==> qtjambi-remoteobjects-debuginfo-macos-5.15.17.jar: sources/QtJambiRemoteObjects/QRemoteObjectDynamicReplica_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtCore/QVariant>
#include <QtCore/QList>
#include <QtCore/qbytearray.h>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qremoteobjectpendingcall.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <QtCore/qtimer.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qcoreevent.h>
#include <QtCore/qthread.h>
#include <QtCore/qnamespace.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QRemoteObjectDynamicReplica(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QRemoteObjectDynamicReplica>("QRemoteObjectDynamicReplica", "io/qt/remoteobjects/QRemoteObjectDynamicReplica");
// BEGIN: function table
// END: function table

    registerCustomMetaObject(typeId, QRemoteObjectDynamicReplica::staticMetaObject);
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QRemoteObjectReplica), typeId, [](void *ptr, qintptr& offset) -> bool {
            QRemoteObjectReplica *object = reinterpret_cast<QRemoteObjectReplica *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = dynamic_cast<QRemoteObjectDynamicReplica*>(object);
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-remoteobjects-debuginfo-macos-6.5.3.jar: sources/QtJambiRemoteObjects/QRemoteObjectDynamicReplica_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/QList>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtRemoteObjects/qremoteobjectpendingcall.h>
#include <QtCore/qobject.h>
#include <QtCore/qtimer.h>
#include <QtCore/qcoreevent.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qmetaobject.h>
#include <QtCore/qthread.h>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qproperty.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QRemoteObjectDynamicReplica(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QRemoteObjectDynamicReplica>("QRemoteObjectDynamicReplica", "io/qt/remoteobjects/QRemoteObjectDynamicReplica");
// BEGIN: function table
// END: function table

    registerCustomMetaObject(typeId, QRemoteObjectDynamicReplica::staticMetaObject);
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QRemoteObjectReplica), typeId, [](void *ptr, qintptr& offset) -> bool {
            QRemoteObjectReplica *object = reinterpret_cast<QRemoteObjectReplica *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = dynamic_cast<QRemoteObjectDynamicReplica*>(object);
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
